==> segatex-8.500.tar.gz: segatex-8.500/src/policygeneration_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qpushbutton.h>
#include <q3process.h>
//Added by qt3to4:
#include <QLabel>
#include <Q3HBoxLayout>
#include <Q3VBoxLayout>

#include "policygeneration_process.h"

//#include <iostream>
//using namespace std;

//default constructor
PolicygenerationProcess::PolicygenerationProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Error"));
	policygenerationLabel = new QLabel(tr("policy_module name empty or executable path empty or file exists."), this );
	closeButton = new QPushButton(tr("close"), this);
	closeButton->setDefault(true);
	//closing yum_process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	//connect(closeButton, SIGNAL(clicked()), this, SLOT(close_button_clicked()));

	Q3VBoxLayout *headLayout = new Q3VBoxLayout;
	headLayout->addWidget(policygenerationLabel);

	Q3HBoxLayout *footLayout = new Q3HBoxLayout;
	footLayout->addStretch(1);
	footLayout->addWidget(closeButton);

	Q3VBoxLayout *mainLayout = new Q3VBoxLayout(this);
	mainLayout->setMargin(11);
	mainLayout->setSpacing(6);
	mainLayout->addLayout(headLayout);
	mainLayout->addLayout(footLayout);
	resize(100,50);

}
/*
void PolicygenerationProcess::close_button_clicked()
{
	cout << "policygeneration process close_button_clicked" << endl;
}
*/

==> segatex-8.640.tar.gz: segatex-8.640/src/policygeneration_process.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <QLayout>
#include <QPushButton>
#include <q3process.h>
//Added by qt3to4:
#include <QLabel>
#include <QHBoxLayout>
#include <QVBoxLayout>

#include "policygeneration_process.h"

//#include <iostream>
//using namespace std;

//constructor
PolicygenerationProcess::PolicygenerationProcess(QWidget *parent, const char *name): QDialog(parent, name)
{
	setCaption(tr("Error"));
	policygenerationLabel = new QLabel(tr("policy_module name empty or executable path empty or file exists."), this );
	closeButton = new QPushButton(tr("close"), this);
	closeButton->setDefault(true);
	//closing yum_process button
	connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
	//connect(closeButton, SIGNAL(clicked()), this, SLOT(close_button_clicked()));

	QVBoxLayout *headLayout = new QVBoxLayout;
	headLayout->addWidget(policygenerationLabel);

	QHBoxLayout *footLayout = new QHBoxLayout;
	footLayout->addStretch(1);
	footLayout->addWidget(closeButton);

	QVBoxLayout *mainLayout = new QVBoxLayout(this);
	mainLayout->setMargin(11);
	mainLayout->setSpacing(6);
	mainLayout->addLayout(headLayout);
	mainLayout->addLayout(footLayout);
	resize(100,50);

}
/*
void PolicygenerationProcess::close_button_clicked()
{
	cout << "policygeneration process close_button_clicked" << endl;
}
*/
